@@ -1,16 +1,78 @@
-# functions on the move from quantmod to xts
-# all should remain unexported until transition
-# is complete - jar
 #
-# periodicity
-# print.periodicity
-# apply.daily
-# apply.weekly
-# apply.monthly
-# apply.quarterly
-# apply.yearly
+#   xts: eXtensible time-series 
+#
+#   Copyright (C) 2008  Jeffrey A. Ryan jeff.a.ryan @ gmail.com
+#
+#   Contributions from Joshua M. Ulrich
+#
+#   This program is free software: you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation, either version 3 of the License, or
+#   (at your option) any later version.
+#
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License
+#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-`periodicity` <-
+
+`periodicity` <- function(x, ...) {
+  if( timeBased(x) || !is.xts(x) )
+    x <- try.xts(x, error='periodicity need to be timeBased or xtsible')
+
+  p <- median(diff( .index(x) ))
+
+  if( is.na(p) ) stop("can not calculate periodicity of 1 observation")
+
+  units <- 'days' # the default if p > hourly
+  scale <- 'years'# the default for p > quarterly
+
+  if( p <= 1 ) {
+    # 86400 / 24 / 60 / 60
+    units <- 'secs'
+    scale <- 'seconds'
+  } else 
+  if( p <= 60 ) {
+    # 86400 / 24 / 60
+    units <- 'mins'
+    scale <- 'minute'
+  } else
+  if( p <= 3600 ) {
+    # 86400 / 24
+    units <- 'hours'
+    scale <- 'hourly'
+  } else
+  if( p <= 86400 ) {
+    # 86400 * 1
+    scale <- 'daily'
+  } else
+  if( p <= 604800) {
+    # 86400 * 7
+    scale <- 'weekly'
+  } else 
+  if( p <= 2678400 ) {
+    # 86400 * 31
+    scale <- 'monthly'
+  } else
+  if( p <= 7862400 ) {
+    # 86400 * 91
+    scale <- 'quarterly'
+  }
+
+  structure(list( difftime = structure(p,units=units,class='difftime'),
+                 frequency = p,
+                     start = start(x),
+                       end = end(x),
+                     units = units,
+                     scale = scale),
+            class = 'periodicity') 
+  
+}
+
+`periodicity.old` <-
 function (x, ...) 
 {
     if(!is.xts(x)) x <- as.xts(x)
