@@ -1,11 +1,33 @@
+#
+#   xts: eXtensible time-series 
+#
+#   Copyright (C) 2008  Jeffrey A. Ryan jeff.a.ryan @ gmail.com
+#
+#   Contributions from Joshua M. Ulrich
+#
+#   This program is free software: you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation, either version 3 of the License, or
+#   (at your option) any later version.
+#
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License
+#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
 # functions to handle timeSeries <--> xts conversions
 
 `re.timeSeries` <-
 function(x,...) {
-  stopifnot("package:fSeries" %in% search() || require("fSeries", quietly=TRUE))
+  stopifnot("package:timeSeries" %in% search() || require("timeSeries", quietly=TRUE))
 
   # strip all non-'core' attributes so they're not attached to the Data slot
   x.attr <- attributes(x)
+  x.index <- index(x)
   xx <- structure(x,dimnames=x.attr$dimnames,index=x.attr$index)
   original.attr <- attributes(x)[!names(attributes(x)) %in% 
                                  c("dim","dimnames","index","class")]
@@ -13,7 +35,7 @@ function(x,...) {
     attr(xx,i) <- NULL
   }
 
-  timeSeries(xx,charvec=as.character(index(xx)),format=x.attr$format,
+  timeSeries(coredata(xx),charvec=as.character(x.index),format=x.attr$format,
              zone=x.attr$FinCenter,FinCenter=x.attr$FinCenter,
              recordIDs=x.attr$recordIDs,title=x.attr$title,
              documentation=x.attr$documentation,...)
@@ -33,7 +55,7 @@ function(x,dateFormat="POSIXct",FinCenter,recordIDs,title,documentation,...) {
 
   order.by <- do.call(paste('as',dateFormat,sep='.'),list(x@positions))
 
-  xts(as.matrix(x@Data),
+  xts(as.matrix(x@.Data),  
       order.by=order.by,
       format=x@format,
       FinCenter=FinCenter,
